@@ -1,7 +1,7 @@
 """
 MIT License
 
-Copyright (c) 2021 Defxult#8269
+Copyright (c) 2021-present Defxult#8269
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -22,12 +22,13 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 
-from functools import wraps
 import os
+from functools import wraps
 
 import aiosqlite
 
-from .errors import DatabaseFileNotFound, LeaderboardNotFound, ImproperLeaderboard, NotConnected
+from .errors import DatabaseFileNotFound, ImproperLeaderboard, LeaderboardNotFound, NotConnected
+
 
 def _return_self(args: list):
     """Return the class instance"""
@@ -46,11 +47,11 @@ def db_file_exists(func):
             traceback, and if the path does exist, return `True`"""
             nonlocal instance
             try:
-                existance = os.path.exists(instance._database_file_path)
+                existence = os.path.exists(instance._database_file_path)
             except TypeError:
                 raise NotConnected
             else:
-                return existance
+                return existence
 
         # if it gets this far, that means :meth:`DiscordLevelingSystem.connect_to_file()` was ran, the connection
         # object was set, the file path was stored, and that file does end in ".db". This checks it again because
