@@ -1,7 +1,7 @@
 """
 MIT License
 
-Copyright (c) 2021 Defxult#8269
+Copyright (c) 2021-present Defxult#8269
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -22,15 +22,16 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 
-import collections
-from typing import List, Union, Dict
+from collections import Counter
+from typing import Dict, List, Union
+
+from .errors import ImproperRoleAwardOrder, RoleAwardError
 
-from .errors import RoleAwardError, ImproperRoleAwardOrder
 
 class RoleAward:
     """Represents the role that will be awarded to the member upon meeting the XP requirement
 
-    Attributes
+    Parameters
     ----------
     role_id: :class:`int`
         ID of the role that is to be awarded
@@ -38,35 +39,35 @@ class RoleAward:
     level_requirement: :class:`int`
         What level is required for a member to be awarded the role
     
-    role_name: :class:`str`:
-        (optional) An optional name. Nothing is done with this value, it is used for visual identification purposes (defaults to :class:`None`)
+    role_name: :class:`str`
+        (optional) An optional name. Nothing is done with this value, it is used for visual identification purposes only (defaults to :class:`None`)
     
-        .. changes::
-            v0.0.2
-                Added :attr:`role_name`
-                Removed :attr:`_level_container`
-                Removed :attr:`_role_id_container`
+    Attributes
+    ----------
+    - `role_id`
+    - `level_requirement`
+    - `role_name`
+    - `mention`
     """
 
-    __slots__ = ('role_id', 'level_requirement', 'role_name')
+    __slots__ = ('role_id', 'level_requirement', 'role_name', 'mention')
 
     def __init__(self, role_id: int, level_requirement: int, role_name: str=None):
         self.role_id = role_id
         self.level_requirement = level_requirement
+        
+        # v0.0.2
         self.role_name = role_name
+        
+        # v1.0.0
+        self.mention = f'<@&{role_id}>'
 
     def __repr__(self):
         return f'<RoleAward role_id={self.role_id} level_requirement={self.level_requirement} role_name={self.role_name!r}>'
     
     def __eq__(self, value):
         if isinstance(value, RoleAward):
-            same_id = False
-            same_lvl_req = False
-            if self.role_id == value.role_id:
-                same_id = True
-            if self.level_requirement == value.level_requirement:
-                same_lvl_req = True
-            return all([same_id, same_lvl_req])
+            return all([self.role_id == value.role_id, self.level_requirement == value.level_requirement])
         else:
             return False
     
@@ -94,14 +95,14 @@ class RoleAward:
         
             .. added:: v0.0.2
         """
-        counter = collections.Counter(guild_ids)
+        counter = Counter(guild_ids)
         if max(counter.values()) != 1:
             raise RoleAwardError('When assigning role awards, all guild IDs must be unique')
 
     @staticmethod
     def _role_id_check(awards: List['RoleAward']):
-        """|static method| ensure all IDs are unique"""
-        role_id_counter = collections.Counter([award.role_id for award in awards])
+        """|static method| Ensure all IDs are unique"""
+        role_id_counter = Counter([award.role_id for award in awards])
         if max(role_id_counter.values()) != 1:
             raise RoleAwardError("There cannot be duplicate ID numbers when using role awards. All ID's must be unique")
     
@@ -109,7 +110,7 @@ class RoleAward:
     def _level_req_check(awards: List['RoleAward']):
         """|static method| Ensures all level requirements/level requirements values are unique and greater than zero"""
         # ensure all level requirements are unique
-        lvl_req_counter = collections.Counter([award.level_requirement for award in awards])
+        lvl_req_counter = Counter([award.level_requirement for award in awards])
         if max(lvl_req_counter.values()) != 1:
             raise RoleAwardError("There cannot be duplicate level requirements when using role awards. All level requirements must be unique")
         
@@ -122,7 +123,7 @@ class RoleAward:
     def _verify_duplicate_awards(awards: List['RoleAward']):
         """|static method| Only used in the :class:`DiscordLevelingSystem` constructor. Ensures all :class:`RoleAward` objects submitted are unique"""
         object_ids = [id(obj) for obj in awards]
-        counter = collections.Counter(object_ids)
+        counter = Counter(object_ids)
         if max(counter.values()) != 1:
             raise RoleAwardError('There cannot be duplicate role award objects when setting the "awards"')
     
